==> mayan-edms-2.7.2.tar.gz: mayan-edms-2.7.2/mayan/apps/document_parsing/models.py <==
from __future__ import unicode_literals

from django.db import models
from django.utils.encoding import force_text, python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _

from documents.models import DocumentPage, DocumentVersion

from .managers import DocumentPageContentManager


@python_2_unicode_compatible
class DocumentPageContent(models.Model):
    document_page = models.OneToOneField(
        DocumentPage, on_delete=models.CASCADE, related_name='content',
        verbose_name=_('Document page')
    )
    content = models.TextField(blank=True, verbose_name=_('Content'))

    objects = DocumentPageContentManager()

    def __str__(self):
        return force_text(self.document_page)

    class Meta:
        verbose_name = _('Document page content')
        verbose_name_plural = _('Document pages contents')


@python_2_unicode_compatible
class DocumentVersionParseError(models.Model):
    document_version = models.ForeignKey(
        DocumentVersion, on_delete=models.CASCADE,
        related_name='parsing_errors', verbose_name=_('Document version')
    )
    datetime_submitted = models.DateTimeField(
        auto_now_add=True, db_index=True, verbose_name=_('Date time submitted')
    )
    result = models.TextField(blank=True, null=True, verbose_name=_('Result'))

    def __str__(self):
        return force_text(self.document_version)

    class Meta:
        ordering = ('datetime_submitted',)
        verbose_name = _('Document version parse error')
        verbose_name_plural = _('Document version parse errors')

==> mayan-edms-3.0.3.tar.gz: mayan-edms-3.0.3/mayan/apps/document_parsing/models.py <==
from __future__ import unicode_literals

from django.db import models
from django.utils.encoding import force_text, python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _

from documents.models import DocumentPage, DocumentType, DocumentVersion

from .managers import DocumentPageContentManager


@python_2_unicode_compatible
class DocumentPageContent(models.Model):
    document_page = models.OneToOneField(
        on_delete=models.CASCADE, related_name='content', to=DocumentPage,
        verbose_name=_('Document page')
    )
    content = models.TextField(blank=True, verbose_name=_('Content'))

    objects = DocumentPageContentManager()

    class Meta:
        verbose_name = _('Document page content')
        verbose_name_plural = _('Document pages contents')

    def __str__(self):
        return force_text(self.document_page)


class DocumentTypeSettings(models.Model):
    document_type = models.OneToOneField(
        on_delete=models.CASCADE, related_name='parsing_settings',
        to=DocumentType, unique=True, verbose_name=_('Document type')
    )
    auto_parsing = models.BooleanField(
        default=True,
        verbose_name=_('Automatically queue newly created documents for parsing.')
    )

    class Meta:
        verbose_name = _('Document type settings')
        verbose_name_plural = _('Document types settings')


@python_2_unicode_compatible
class DocumentVersionParseError(models.Model):
    document_version = models.ForeignKey(
        on_delete=models.CASCADE, related_name='parsing_errors',
        to=DocumentVersion, verbose_name=_('Document version')
    )
    datetime_submitted = models.DateTimeField(
        auto_now_add=True, db_index=True, verbose_name=_('Date time submitted')
    )
    result = models.TextField(blank=True, null=True, verbose_name=_('Result'))

    class Meta:
        ordering = ('datetime_submitted',)
        verbose_name = _('Document version parse error')
        verbose_name_plural = _('Document version parse errors')

    def __str__(self):
        return force_text(self.document_version)
